@@ -25,7 +25,7 @@ class Module:
 
   Arguments:
     filepath: The file path of the module. From the derived class scope, it should be ``__file__``. The ``filepath`` argument is used to retrieve the module *YAML* specification file.
-    context: The ``laboro.context.Context`` associated with the ``laboro.workflow.Workflow`` instance instantiating the module. The ``context`` will be automatically provided by the workflow.
+    context: The ``laboro.context.Context`` associated with the ``Workflow``, ``Step`` or ``Action`` instance instantiating the module. It will be automatically provided.
     args: A kwargs representing the module instance arguments.
 
   Returns:
@@ -53,8 +53,7 @@ class Module:
         method_args = Validator().set_default_method_args(method, kwargs)
       except IndexError as err:
         raise LaboroError(f"UnknownMethodError: Unknown method: {method}") from err
-      self.context.put(func.__name__, func(self, **method_args))
-      return self.context.get(func.__name__)
+      return func(self, **method_args)
     return wrapper
 
   def __enter__(self):
